==> qq-bot-0.2.4.tar.gz: qq-bot-0.2.4/qqbot/model/guild_role.py <==
# -*- coding: utf-8 -*-

from qqbot.model.channel import Channel


class Role:
    def __init__(self, data=None):
        self.id = ""
        self.name = ""
        self.color = 0
        self.hoist = 0
        self.number = 0
        self.number_limit = 0
        if data is not None:
            self.__dict__ = data


class GuildRoles:
    def __init__(self, data=None):
        self.guild_id = ""
        self.roles = [Role()]
        self.role_num_limit = ""
        if data is not None:
            self.__dict__ = data


class RoleUpdateRequest:
    def __init__(self, data=None):
        self.guild_id = ""
        self.filter: [RoleUpdateFilter] = None
        self.info: [RoleUpdateInfo] = None
        if data is not None:
            self.__dict__ = data


class RoleUpdateFilter:
    def __init__(self, name, color, hoist):
        self.name = name
        self.color = color
        self.hoist = hoist


class RoleUpdateInfo:
    def __init__(self, name, color, hoist):
        """
        身份组更新的信息

        :param name:名称
        :param color:ARGB的HEX十六进制颜色值转换后的十进制数值
        :param hoist:在成员列表中单独展示: 0-否, 1-是
        """
        self.name = name
        self.color = color
        self.hoist = hoist


class RoleUpdateResult:
    def __init__(self, data=None):
        self.guild_id = ""
        self.role_id = ""
        self.role = Role()
        if data is not None:
            self.__dict__ = data


class RoleMemberRequest:
    def __init__(self, data=None):
        self.channel: [Channel] = None

==> qq-bot-0.6.7.tar.gz: qq-bot-0.6.7/qqbot/model/guild_role.py <==
# -*- coding: utf-8 -*-
from typing import List


class Role:
    def __init__(self, data=None):
        self.id: str = ""
        self.name: str = ""
        self.color: int = 0
        self.hoist: int = 0
        self.number: int = 0
        self.number_limit: int = 0
        if data is not None:
            self.__dict__ = data


class GuildRoles:
    def __init__(self, data=None):
        self.guild_id: str = ""
        self.roles: List[Role] = [Role()]
        self.role_num_limit: str = ""
        if data is not None:
            self.__dict__ = data


class RoleUpdateRequest:
    def __init__(self, data=None):
        self.guild_id: str = ""
        self.filter: [RoleUpdateFilter] = None
        self.info: [RoleUpdateInfo] = None
        if data is not None:
            self.__dict__ = data


class RoleUpdateFilter:
    def __init__(self, name: int, color: int, hoist: int):
        self.name = name
        self.color = color
        self.hoist = hoist


class RoleUpdateInfo:
    def __init__(self, name: str, color: int, hoist: int):
        """
        身份组更新的信息

        :param name:名称
        :param color:ARGB的HEX十六进制颜色值转换后的十进制数值
        :param hoist:在成员列表中单独展示: 0-否, 1-是
        """
        self.name = name
        self.color = color
        self.hoist = hoist


class RoleUpdateResult:
    def __init__(self, data=None):
        self.guild_id: str = ""
        self.role_id: str = ""
        self.role: Role = Role()
        if data is not None:
            self.__dict__ = data
